@@ -37,7 +37,7 @@ BackGnd::BackGnd(QGraphicsScene *scene, const GameLogic::ONU* theWorld, bool are
     QGraphicsPixmapItem(0), m_theWorld(theWorld), m_bgIsArena(arena)
 {
   scene->addItem(this);
-  qCDebug(KSIRK_LOG) << "BackGnd constructor" << endl;
+  qCDebug(KSIRK_LOG) << "BackGnd constructor";
 
   QPixmap pix;
   if (arena == false) {
